@@ -164,7 +164,7 @@ struct backend
   u_int loaded:1;		/* are the functions available? */
   u_int inited:1;		/* has the backend been initialized? */
   void *handle;			/* handle returned by dlopen() */
-  void *(*op[NUM_OPS]) ();
+  void *(*op[NUM_OPS]) (void);
 };
 
 #define BE_ENTRY(be,func)       sane_##be##_##func
@@ -385,14 +385,16 @@ load (struct backend *be)
 # ifdef __hpux
 #   define POSTFIX ".sl.%u"
 #   define ALT_POSTFIX ".so.%u"
-#elif defined (HAVE_WINDOWS_H)
+# elif defined (HAVE_WINDOWS_H)
 #   undef PREFIX
 #   define PREFIX "cygsane-"
 #   define POSTFIX "-%u.dll"
-#elif defined (HAVE_OS2_H)
+# elif defined (HAVE_OS2_H)
 #   undef PREFIX
 #   define PREFIX ""
 #   define POSTFIX ".dll"
+# elif defined (__APPLE__) && defined (__MACH__)
+#   define POSTFIX ".%u.so"
 # else
 #   define POSTFIX ".so.%u"
 # endif
