@@ -2,7 +2,7 @@
    tstbackend -- backend test utility
 
    Uses the SANE library.
-   Copyright (C) 2002 Frank Zago (fzago@greshamstorage.com)
+   Copyright (C) 2002 Frank Zago (sane at zago dot net)
 
    This file is part of the SANE package.
 
@@ -22,7 +22,7 @@
    MA 02111-1307, USA.
 */
 
-#define BUILD 16				/* 2002-04-19 */
+#define BUILD 18				/* 2003-02-22 */
 
 #include "../include/sane/config.h"
 
@@ -63,7 +63,12 @@ enum message_level {
 
 int message_number_wrn = 0;
 int message_number_err = 0;
+#ifdef HAVE_LONG_LONG
 long long checks_done = 0;
+#else
+/* It may overflow, but it's no big deal. */
+long int checks_done = 0;
+#endif
 
 int test_level;
 
@@ -75,8 +80,13 @@ int test_level;
 /* Display the message error statistics. */
 static void display_stats(void)
 {
+#ifdef HAVE_LONG_LONG
 	printf("warnings: %d  error: %d  checks: %lld\n", 
 		   message_number_wrn, message_number_err, checks_done);
+#else
+	printf("warnings: %d  error: %d  checks: %ld\n", 
+		   message_number_wrn, message_number_err, checks_done);
+#endif
 }
 
 /* 
@@ -180,7 +190,7 @@ static void guards_set(void *ptr, size_t size)
 	*p = GUARD2;
 }
 
-/* Check that the guards have not been tampered. */
+/* Check that the guards have not been tampered with. */
 static void guards_check(void *ptr, size_t size)
 {
 	SANE_Word *p;
@@ -1186,6 +1196,11 @@ static void test_scan(SANE_Handle device)
 			  "sane_set_io_mode with SANE_TRUE returned an invalid status (%s)", 
 			  sane_strstatus (status));
 
+		/* Put the backend back into blocking mode. */
+		status = sane_set_io_mode (device, SANE_FALSE);
+		check(ERR, (status == SANE_STATUS_GOOD),
+			  "sane_set_io_mode with SANE_FALSE must return SANE_STATUS_GOOD");
+
 		/* Test sane_get_select_fd */
 		fd = 0x76575;				/* won't exists */
 		status = sane_get_select_fd(device, &fd);
@@ -1196,7 +1211,7 @@ static void test_scan(SANE_Handle device)
 		if (status == SANE_STATUS_GOOD) {
 			check(ERR, (fd != 0x76575),
 				  "sane_get_select_fd didn't set the fd although it should have");
-			check(ERR, (fd < 0),
+			check(ERR, (fd >= 0),
 				  "sane_get_select_fd returned an invalid fd");
 		}
 	
@@ -1612,6 +1627,7 @@ main (int argc, char **argv)
 	/* First test */
 	check(MSG, 0, "TEST: init/exit");
 	for (i=0; i<10; i++) {
+		/* Test 1. init/exit with a version code */
 		status = sane_init(&version_code, NULL);
 		check(FATAL, (status == SANE_STATUS_GOOD),
 			  "sane_init failed with %s", sane_strstatus (status));
@@ -1619,10 +1635,44 @@ main (int argc, char **argv)
 			  "invalid SANE version linked");
 		sane_exit();
 
+		/* Test 2. init/exit without a version code */
 		status = sane_init(NULL, NULL);
 		check(FATAL, (status == SANE_STATUS_GOOD),
 			  "sane_init failed with %s", sane_strstatus (status));
 		sane_exit();
+
+		/* Test 3. Init/get_devices/open invalid/exit */
+		status = sane_init(NULL, NULL);
+		check(FATAL, (status == SANE_STATUS_GOOD),
+			  "sane_init failed with %s", sane_strstatus (status));
+
+		status = sane_get_devices (&device_list, SANE_TRUE);
+		check(FATAL, (status == SANE_STATUS_GOOD),
+			  "sane_get_devices() failed (%s)", sane_strstatus (status));
+
+		status = sane_open ("opihndvses75bvt6fg", &device);
+		check(WRN, (status == SANE_STATUS_INVAL),
+			  "sane_open() failed (%s)", sane_strstatus (status));
+		
+		if (status == SANE_STATUS_GOOD)
+			sane_close(device);
+
+		sane_exit();
+
+		/* Test 4. Init/get_devices/open default/exit */
+		status = sane_init(NULL, NULL);
+		check(FATAL, (status == SANE_STATUS_GOOD),
+			  "sane_init failed with %s", sane_strstatus (status));
+
+		status = sane_get_devices (&device_list, SANE_TRUE);
+		check(FATAL, (status == SANE_STATUS_GOOD),
+			  "sane_get_devices() failed (%s)", sane_strstatus (status));
+
+		status = sane_open ("", &device);
+		if (status == SANE_STATUS_GOOD)
+			sane_close(device);
+
+		sane_exit();
 	}
 
 	status = sane_init (&version_code, NULL);
@@ -1674,15 +1724,18 @@ main (int argc, char **argv)
 					(strcmp(dev->vendor, "Hewlett-Packard") == 0) ||
 					(strcmp(dev->vendor, "IBM") == 0) ||
 					(strcmp(dev->vendor, "Kodak") == 0) ||
+                                        (strcmp(dev->vendor, "Lexmark") == 0) ||
 					(strcmp(dev->vendor, "Logitech") == 0) ||
 					(strcmp(dev->vendor, "Microtek") == 0) ||
 					(strcmp(dev->vendor, "Minolta") == 0) ||
+					(strcmp(dev->vendor, "Mitsubishi") == 0) ||
 					(strcmp(dev->vendor, "Mustek") == 0) ||
 					(strcmp(dev->vendor, "NEC") == 0) ||
 					(strcmp(dev->vendor, "Nikon") == 0) ||
 					(strcmp(dev->vendor, "Noname") == 0) ||
 					(strcmp(dev->vendor, "Plustek") == 0) ||
 					(strcmp(dev->vendor, "Polaroid") == 0) ||
+					(strcmp(dev->vendor, "Relisys") == 0) ||
 					(strcmp(dev->vendor, "Ricoh") == 0) ||
 					(strcmp(dev->vendor, "Sharp") == 0) ||
 					(strcmp(dev->vendor, "Siemens") == 0) ||
